==> SV1000-Linux.SV1.2.109.tar.gz: SpliceCom/WebManager/admin/managecontacts/loadContact.php <==
<?php

$contactMode = (isset($_REQUEST['contactMode']) && strlen($_REQUEST['contactMode']) >=1) 	? $_REQUEST['contactMode'] 	: '';
$contactGuid = (isset($_REQUEST['contactGuid']) && strlen($_REQUEST['contactGuid']) >=1) 	? $_REQUEST['contactGuid'] 	: '';
$contactNumber = (isset($_REQUEST['contactNumber']) && strlen($_REQUEST['contactNumber']) >=1) ? $_REQUEST['contactNumber'] : '';
$selectedCompany = (isset($_REQUEST['selectedCompany']) && strlen($_REQUEST['selectedCompany']) >=1) ? $_REQUEST['selectedCompany'] : '0';

if ($contactMode == 'addContact')	{
	$contactText = 'Add Contact Entry';
	$contactClass = 'icon-plus';
} else {
	$contactText = ' - Edit Contact Entry';
	$contactClass = 'icon-pencil2';
}

if ($contactMode == 'editContact') {
	
	if ($selectedCompany === '0') {
		$dn = "cn=Contacts";
	} else {
		$dn = "cn=contacts, cn=$selectedCompany, cn=Companies";
	}
	
	$sr=ldap_list($ds,$dn,"(&(objectclass=*)(guid=$contactGuid))");
	
	$info = ldap_get_entries($ds, $sr); 
	$cn = (isset($info[0]['cn'][0]) && strlen($info[0]['cn'][0]) >=1) ? $info[0]['cn'][0] : '';
	$o 	= (isset($info[0]['o'][0]) && strlen($info[0]['o'][0]) >=1) ? $info[0]['o'][0] : '';
	$description = (isset($info[0]['description'][0]) && strlen($info[0]['description'][0]) >=1) ? $info[0]['description'][0] : '';
	$telephonenumber = (isset($info[0]['telephonenumber'][0]) && strlen($info[0]['telephonenumber'][0]) >=1) ? $info[0]['telephonenumber'][0] : '';
	$mobiletelephonenumber 	= (isset($info[0]['mobiletelephonenumber'][0]) && strlen($info[0]['mobiletelephonenumber'][0]) >=1) ? $info[0]['mobiletelephonenumber'][0] : '';
	$hometelephonenumber = (isset($info[0]['hometelephonenumber'][0]) && strlen($info[0]['hometelephonenumber'][0]) >=1) ? $info[0]['hometelephonenumber'][0] : '';
	$spare1telephonenumber = (isset($info[0]['spare1telephonenumber'][0]) && strlen($info[0]['spare1telephonenumber'][0]) >=1) ? $info[0]['spare1telephonenumber'][0] : '';
	$spare2telephonenumber = (isset($info[0]['spare2telephonenumber'][0]) && strlen($info[0]['spare2telephonenumber'][0]) >=1) ? $info[0]['spare2telephonenumber'][0] : '';
	$directrouteto = (isset($info[0]['directrouteto'][0]) && strlen($info[0]['directrouteto'][0]) >=1) ? $info[0]['directrouteto'][0] : '';
	$mail = (isset($info[0]['mail'][0]) && strlen($info[0]['mail'][0]) >=1) ? $info[0]['mail'][0] : '';
	$priorityboost = (isset($info[0]['priorityboost'][0]) && strlen($info[0]['priorityboost'][0]) >=1) ? $info[0]['priorityboost'][0] : '';
	$ouraccount = (isset($info[0]['ouraccount'][0]) && strlen($info[0]['ouraccount'][0]) >=1) ? $info[0]['ouraccount'][0] : '';
	$theiraccount = (isset($info[0]['theiraccount'][0]) && strlen($info[0]['theiraccount'][0]) >=1) ? $info[0]['theiraccount'][0] : '';
	$ambiguoustelephonenumber = (isset($info[0]['ambiguoustelephonenumber'][0]) && strlen($info[0]['ambiguoustelephonenumber'][0]) >=1) ? $info[0]['ambiguoustelephonenumber'][0] : '';
} else {
	$cn = $o = $description = $telephonenumber = $mobiletelephonenumber = $hometelephonenumber = $spare1telephonenumber = $spare2telephonenumber = $directrouteto = $mail = $priorityboost = $ouraccount = $theiraccount = $ambiguoustelephonenumber = '';
}
?>

==> SV1000-Linux.SV1.3.117.tar.gz: SpliceCom/WebManager/admin/managecontacts/loadContact.php <==
<?php

$contactMode = (isset($_REQUEST['contactMode']) && strlen($_REQUEST['contactMode']) >=1) 	? $_REQUEST['contactMode'] 	: '';
$contactGuid = (isset($_REQUEST['contactGuid']) && strlen($_REQUEST['contactGuid']) >=1) 	? $_REQUEST['contactGuid'] 	: '';
$contactNumber = (isset($_REQUEST['contactNumber']) && strlen($_REQUEST['contactNumber']) >=1) ? $_REQUEST['contactNumber'] : '';
$selectedCompany = (isset($_REQUEST['selectedCompany']) && strlen($_REQUEST['selectedCompany']) >=1) ? $_REQUEST['selectedCompany'] : '0';

if ($contactMode == 'addContact')	{
	$contactText = 'Add Contact Entry';
	$contactClass = 'icon-plus';
} else {
	$contactText = ' - Edit Contact Entry';
	$contactClass = 'icon-pencil2';
}

if ($contactMode == 'editContact') {
	
	if ($selectedCompany === '0') {
		$dn = "cn=Contacts";
	} else {
		$dn = "cn=contacts, cn=$selectedCompany, cn=Companies";
	}
	
	$sr=ldap_list($ds,$dn,"(&(objectclass=*)(guid=$contactGuid))");
	
	$info = ldap_get_entries($ds, $sr); 
	$cn = (isset($info[0]['cn'][0]) && strlen($info[0]['cn'][0]) >=1) ? $info[0]['cn'][0] : '';
	$o 	= (isset($info[0]['o'][0]) && strlen($info[0]['o'][0]) >=1) ? $info[0]['o'][0] : '';
	$description = (isset($info[0]['description'][0]) && strlen($info[0]['description'][0]) >=1) ? $info[0]['description'][0] : '';
	$telephonenumber = (isset($info[0]['telephonenumber'][0]) && strlen($info[0]['telephonenumber'][0]) >=1) ? $info[0]['telephonenumber'][0] : '';
	$mobiletelephonenumber 	= (isset($info[0]['mobiletelephonenumber'][0]) && strlen($info[0]['mobiletelephonenumber'][0]) >=1) ? $info[0]['mobiletelephonenumber'][0] : '';
	$hometelephonenumber = (isset($info[0]['hometelephonenumber'][0]) && strlen($info[0]['hometelephonenumber'][0]) >=1) ? $info[0]['hometelephonenumber'][0] : '';
	$spare1telephonenumber = (isset($info[0]['spare1telephonenumber'][0]) && strlen($info[0]['spare1telephonenumber'][0]) >=1) ? $info[0]['spare1telephonenumber'][0] : '';
	$spare2telephonenumber = (isset($info[0]['spare2telephonenumber'][0]) && strlen($info[0]['spare2telephonenumber'][0]) >=1) ? $info[0]['spare2telephonenumber'][0] : '';
	$directrouteto = (isset($info[0]['directrouteto'][0]) && strlen($info[0]['directrouteto'][0]) >=1) ? $info[0]['directrouteto'][0] : '';
	$mail = (isset($info[0]['mail'][0]) && strlen($info[0]['mail'][0]) >=1) ? $info[0]['mail'][0] : '';
	$priorityboost = (isset($info[0]['priorityboost'][0]) && strlen($info[0]['priorityboost'][0]) >=1) ? $info[0]['priorityboost'][0] : '';
	$ouraccount = (isset($info[0]['ouraccount'][0]) && strlen($info[0]['ouraccount'][0]) >=1) ? $info[0]['ouraccount'][0] : '';
	$theiraccount = (isset($info[0]['theiraccount'][0]) && strlen($info[0]['theiraccount'][0]) >=1) ? $info[0]['theiraccount'][0] : '';
	$ambiguoustelephonenumber = (isset($info[0]['ambiguoustelephonenumber'][0]) && strlen($info[0]['ambiguoustelephonenumber'][0]) >=1) ? $info[0]['ambiguoustelephonenumber'][0] : '';
	$firstname = (isset($info[0]['givenname'][0]) && strlen($info[0]['givenname'][0]) >=1) ? $info[0]['givenname'][0] : '';
	$lastname = (isset($info[0]['sn'][0]) && strlen($info[0]['sn'][0]) >=1) ? $info[0]['sn'][0] : '';
} else {
	$cn = $o = $description = $telephonenumber = $mobiletelephonenumber = $hometelephonenumber = $spare1telephonenumber = $spare2telephonenumber = $directrouteto = $mail = $priorityboost = $ouraccount = $theiraccount = $ambiguoustelephonenumber = $firstname = $lastname = '';
}
?>
